==> filemv0.51.0.zip: source/edit.cpp <==
#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <fstream.h>
#include <windows.h>
#include "edit.h"
#include "file.h"
#include "status.h"

#define MAX_EDIT 1024*30
#define editsize MAX_EDIT
char buff[editsize];
char backupbuff[editsize];
char editfile[MAX_PATH];


//㏑ Ă悢t@C`FbN

BOOL checkoverwriteOK(char *file)
{
	setstatusonly(1,"-");
	if(checkExt(file,"exe")) return FALSE;
	if(checkExt(file,"EXE")) return FALSE;
	setstatusonly(1,"+");
	return TRUE;
}

//㏑ Ă悢t@C`FbN

void overwriteNO()
{
	setstatusonly(1,"big");
}

void cnvtoa(char *buf, int de,long len,long denum)
{
	strcpy(backupbuff,buff);
	char *pfrom,*pto;
	pfrom =backupbuff;
	pto =buf;

	for(long i=0; i<len-denum; i++,pfrom++,pto++)
	{
		if(*pfrom!=de) *pto=*pfrom;
		else {
			*pto=13;
			pto++;
			*pto=10;
		}
	}
}

void cnvbuff(char *buf, long len)
{
	int a=0;
	int d=0;
	int da=0;
	for(int i=0; i<1000; i++)
	{
		if(buf[i]==13){
			if( buf[i+1]==10) da++;
			else d++;
		}
		else if(buf[i]==10) a++;
	}
	if(da==0 && a+d>0)
	{
		if(a>3){
			cnvtoa(buf,10,len,a);
		}
		else if(d>3){
			cnvtoa(buf,13,len,d);
		}
	}
}

//edit window \
//t@CݒAe\AeobNAbvobt@ɃRs[iԖʂj
//utf-8ifirefox bookmark.htmȂǁjIƂȂԂH

void setfile(HWND hEdit,char *file,char *dir)
{
	SetWindowText(hEdit,"loading..");
	SetCurrentDirectory(dir);
	_fullpath(editfile,file,MAX_PATH);
	editflag=FALSE;
	memset(buff,0,sizeof(buff));
	memset(backupbuff,0,sizeof(backupbuff));
	ifstream in(editfile,ios::binary | ios::nocreate);
	if(in) in.read(buff,editsize-2);
	cnvbuff(buff,editsize-2);
	strcpy(backupbuff,buff);
	SetWindowText(hEdit,buff);
	checkoverwriteOK(editfile);
	if(getfilesize(file)<editsize-1000)
	{
		editflag=TRUE;
	}
	else
	{
		editflag=FALSE;
		overwriteNO();
	}
		
}

//㏑
//obNAbvobt@ƔrAXVĂꍇ̂݁B

void overwrite(HWND hEdit)
{
	if(editflag)
	{
		memset(buff,0,sizeof(buff));
		GetWindowText(hEdit,buff,editsize-2);
		if(strcmp(backupbuff,buff)!=0 && checkoverwriteOK(editfile)) 
		{
			ofstream ou(editfile,ios::binary);
			ou.write(buff,strlen(buff));
		}
	}
	else
	{
		MessageBox(NULL, "TCY傫㏑ot@Cł͂܂", "Error", MB_OK);
	}
}

//㏑At@C؂ւOɌĂяoAꂢ͌Ă΂Ȃ
void autooverwrite(HWND hEdit)
{
	if(editflag)
	{
		overwrite(hEdit);
	}
}


BOOL geteditflag()
{
	return editflag;
}

void seteditflag(BOOL f)
{
	editflag=f;
}

==> filemv0.52.0.zip: source/edit.cpp <==
#include "defextern.h"

#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <fstream.h>
#include <windows.h>
#include "edit.h"
#include "mes.h"
#include "initial.h"
#include "file.h"
#include "status.h"

#define MAX_EDIT 1024*30
#define editsize MAX_EDIT
char buff[editsize];
char backupbuff[editsize];
char editfile[MAX_PATH];


//㏑ Ă悢t@C`FbN

BOOL checkoverwriteOK(char *file)
{
	setstatusonly(1,"-");
	if(checkExt(file,"exe")) return FALSE;
	if(checkExt(file,"EXE")) return FALSE;
	setstatusonly(1,"+");
	return TRUE;
}

//㏑ Ă悢t@C`FbN

void overwriteNO()
{
	setstatusonly(1,"big");
}

void cnvtoa(char *buf, int de,long len,long denum)
{
	strcpy(backupbuff,buff);
	char *pfrom,*pto;
	pfrom =backupbuff;
	pto =buf;

	for(long i=0; i<len-denum; i++,pfrom++,pto++)
	{
		if(*pfrom!=de) *pto=*pfrom;
		else {
			*pto=13;
			pto++;
			*pto=10;
		}
	}
}

void cnvbuff(char *buf, long len)
{
	int a=0;
	int d=0;
	int da=0;
	for(int i=0; i<1000; i++)
	{
		if(buf[i]==13){
			if( buf[i+1]==10) da++;
			else d++;
		}
		else if(buf[i]==10) a++;
	}
	if(da==0 && a+d>0)
	{
		if(a>3){
			cnvtoa(buf,10,len,a);
		}
		else if(d>3){
			cnvtoa(buf,13,len,d);
		}
	}
}

//edit window \
//t@CݒAe\AeobNAbvobt@ɃRs[iԖʂj
//utf-8ifirefox bookmark.htmȂǁjIƂȂԂH

void setfile(HWND hEdit,char *file,char *dir)
{
	SetWindowText(hEdit,"loading..");
	SetCurrentDirectory(dir);
	_fullpath(editfile,file,MAX_PATH);
	editflag=FALSE;
	memset(buff,0,sizeof(buff));
	memset(backupbuff,0,sizeof(backupbuff));
	ifstream in(editfile,ios::binary | ios::nocreate);
	if(in) in.read(buff,editsize-2);
	cnvbuff(buff,editsize-2);
	strcpy(backupbuff,buff);
	SetWindowText(hEdit,buff);
	checkoverwriteOK(editfile);
	if(getfilesize(file)<editsize-1000)
	{
		editflag=TRUE;
	}
	else
	{
		editflag=FALSE;
		overwriteNO();
	}
		
}

//㏑
//obNAbvobt@ƔrAXVĂꍇ̂݁B

void overwrite(HWND hEdit)
{
	if(editflag)
	{
		memset(buff,0,sizeof(buff));
		GetWindowText(hEdit,buff,editsize-2);
		if(strcmp(backupbuff,buff)!=0 && checkoverwriteOK(editfile)) 
		{
			ofstream ou(editfile,ios::binary);
			ou.write(buff,strlen(buff));
		}
	}
	else
	{
		MessageBox(NULL, "TCY傫㏑ot@Cł͂܂", "Error", MB_OK);
	}
}

//㏑At@C؂ւOɌĂяoAꂢ͌Ă΂Ȃ
void autooverwrite(HWND hEdit)
{
	if(editflag)
	{
		overwrite(hEdit);
	}
}


BOOL geteditflag()
{
	return editflag;
}

void seteditflag(BOOL f)
{
	editflag=f;
}

void saveMemo(HWND hEdit)
{
	char mfile[MAX_PATH];
	char buff[editsize];
	GetFullName(mfile, memofile, memopath, MAX_PATH);
	
	memset(buff,0,sizeof(buff));
	GetWindowText(hEdit,buff,editsize-2); 
	if(strcmp(backupbuff,buff)!=0 ) 
	{
		ofstream ou(mfile,ios::binary);
		ou.write(buff,strlen(buff));
	}
	SetWindowText(hEdit,"");
}

void askmemoname(char *path)
{
	//
}

void loadMemo(HWND hEdit)
{
	if(strlen(memopath)==0)
	{
		askmemoname(memopath);
	}
	if(strlen(memopath)==0)
	{
		strcpy(memopath,getCdir());
	}
	
	char mfile[MAX_PATH];
	GetFullName(mfile, memofile, memopath, MAX_PATH);
	
	memset(buff,0,sizeof(buff));
	ifstream in(mfile,ios::binary | ios::nocreate);
	if(in) in.read(buff,editsize-2);
	cnvbuff(buff,editsize-2);
	strcpy(backupbuff,buff);
	SetWindowText(hEdit,buff);
	//Mes(mfile);
}
